
/* -------------------------------------------------------------------- */
/* Embedded access DLL for USB humidity and temperature sensor devices.	*/
/* -------------------------------------------------------------------- */

#pragma once


/* -------------------------------------------------------------------- */
/* Status codes:							*/

#define SENS_HEATING_ENABLED	      1	/* OK, but heating is enabled	*/
#define SENS_SUCCESS		      0	/* OK, no errors		*/
#define SENS_FAILED		     -1	/* common error code		*/
#define SENS_NOT_FOUND		     -2	/* the drvice was not found	*/
#define SENS_UNABLE_TO_OPEN	     -3	/* unable to open device access	*/
#define SENS_IO_ERROR		     -4	/* communication error		*/
#define SENS_TYPE_NOT_SUPPORTET	     -5	/* not supported sensor type	*/
#define SENS_DEVICE_NOT_READY	     -6	/* sensor is not ready for use	*/
#define SENS_RH_NOT_MEASURED	     -7	/* no humidity value available	*/
#define SENS_TEMP_NOT_MEASURED       -8	/* no temperature value avail.	*/
#define SENS_INVALID_MEASUREMENT     -9	/* unvalid measuring value	*/
#define SENS_INVALID_FUNCTION	    -10	/* invalid function		*/


/* Parameter structures:						*/

typedef struct	_SENSDEVICEA
{
 TCHAR		szSerialNo[32];		/* sensor device serial number	*/
 TCHAR		szDeviceID[32];		/* sensor device ID string	*/
 LONG_PTR	nIndex;			/* device index			*/

} SENSDEVICEA, * PSENSDEVICEA;


typedef struct	_SENSDEVICEW
{
 WCHAR		szSerialNo[32];		/* sensor device serial number	*/
 WCHAR		szDeviceID[32];		/* sensor device ID string	*/
 LONG_PTR	nIndex;			/* device index			*/

} SENSDEVICEW, * PSENSDEVICEW;

#ifdef UNICODE
 #define	SENSDEVICE	SENSDEVICEW 
 #define	PSENSDEVICE	PSENSDEVICEW 
#else
 #define	SENSDEVICE	SENSDEVICEA 
 #define	PSENSDEVICE	PSENSDEVICEA
#endif


/* Exported functions:							*/

extern "C"
{
 _declspec(dllexport)	HRESULT WINAPI	 DllGetVersion(DLLVERSIONINFO * pDllVerInfo);
 
 _declspec(dllexport)	LRESULT	CALLBACK SensFindDevice(LONG_PTR n, LPSTR pszMask, PSENSDEVICEA pDevice);
 _declspec(dllexport)	LRESULT	CALLBACK SensReadValues(PVOID Parameter, BOOL Mode, float * pfValRH, float * pfValTemp, float * pfValDew);
 _declspec(dllexport)	LRESULT	CALLBACK SensSetHeating(PVOID Parameter, BOOL Mode, BOOL bEnable);
 _declspec(dllexport)	BOOL	CALLBACK SensGetChangeFlag(VOID);
 _declspec(dllexport)	BOOL	CALLBACK SensWaitReady(LONG nTimeout);
 
 _declspec(dllexport)	LRESULT	CALLBACK SensFindDeviceA(LONG_PTR n, LPSTR pszMask, PSENSDEVICEA pDevice);
 _declspec(dllexport)	LRESULT	CALLBACK SensReadValuesA(PVOID Parameter, BOOL Mode, float * pfValRH, float * pfValTemp, float * pfValDew);
 _declspec(dllexport)	LRESULT	CALLBACK SensSetHeatingA(PVOID Parameter, BOOL Mode, BOOL bEnable);
 _declspec(dllexport)	BOOL	CALLBACK SensGetChangeFlagA(VOID);
 _declspec(dllexport)	BOOL	CALLBACK SensWaitReadyA(LONG nTimeout);
 
 _declspec(dllexport)	LRESULT	CALLBACK SensFindDeviceW(LONG_PTR n, LPWSTR pwszMask, PSENSDEVICEW pDevice);
 _declspec(dllexport)	LRESULT	CALLBACK SensReadValuesW(PVOID Parameter, BOOL Mode, float * pfValRH, float * pfValTemp, float * pfValDew);
 _declspec(dllexport)	LRESULT	CALLBACK SensSetHeatingW(PVOID Parameter, BOOL Mode, BOOL bEnable);
 _declspec(dllexport)	BOOL	CALLBACK SensGetChangeFlagW(VOID);
 _declspec(dllexport)	BOOL	CALLBACK SensWaitReadyW(LONG nTimeout);
}


/* -------------------------------------------------------------------- */
/* Function ptototypes:							*/

/* Function searches the current device list for the sensor device and	*/
/* fills the parameter block with the sensor parameters. Function	*/
/* returns TRUE if the sensor device was found, otherwise it returns	*/
/* FALSE. For the search a filter string can be used to select a	*/
/* specific sensor device:						*/
/* 									*/
/* Parameter:	Type:		Description:  				*/
/*									*/
/* n		LONG_PTR	Contains the index of the depending	*/
/*				device. The index is starting at 0. The	*/
/*				function returns the data of the n-th.	*/
/*				device if this matches to the given	*/
/*				filter settings.			*/
/* 									*/
/* pszMask	LPSTR		Pointer to a filter string or zero.	*/
/*				If a filter string is defined, only	*/
/*				matching devices are returned.		*/
/* 									*/
/* lpDevice	PSENSDEVICE	Pointer to a buffer of the type		*/
/*				'SENSDEVICE' or zero. If a buffer ptr.	*/
/*				is defined, it will be filled with the	*/
/*				data of the searched sensor, if serach	*/
/*				was successful.				*/
/* 									*/
/* Return type:	BOOL						*/
/* 									*/
/* The function returns TRUE if the searched device was found, otherwise*/
/* it returns FALSE.							*/

#define SDEV_SN_LEN		32	/* max. lenght of serial number	*/
#define SDEV_ID_LEN		32	/* max. lenght of ID string	*/

//_declspec(dllexport)	LRESULT	CALLBACK SensFindDeviceA(LONG_PTR n, LPSTR pszMask, PSENSDEVICEA pDevice);
//_declspec(dllexport)	LRESULT	CALLBACK SensFindDeviceW(LONG_PTR n, LPWSTR pwszMask, PSENSDEVICEW pDevice);

#ifdef UNICODE
 #define	SensFindDevice	SensFindDeviceW 
#else
 //#define	SensFindDevice	SensFindDeviceA
#endif


/* Function reads the values of the device, its serial number was	*/
/* specified. Depending on sensor, readings are not always available:	*/
/* 									*/
/* Parameter:	Type:		Description:  				*/
/*									*/
/* Parameter	PVOID		Parameter, depending on 'bMode'. If	*/
/*				SENS_READ_BY_SERIAL_NUMBER is selected,	*/
/*				'Parameter' is a pointer to a null-	*/
/*				terminated string, which contains the	*/
/*				device serial number of the sensor. If	*/
/*				'bMode' is SENS_READ_BY_INDEX, the	*/
/*				'Parameter' is the device index, used	*/
/*				by the SensFindDevice(n, ...) function	*/
/*				to identify the device.			*/
/*									*/
/* Mode		BOOL		Adressing mode for sensor selection.	*/
/*				As described before, either the device	*/
/*				serial number is used, or the index.	*/
/*									*/
/* pfValRH	float *		Pointer to a float variable (4-bytes	*/
/*				IEEE floating point) for receiving the	*/
/*				latest humidity measuring value. The	*/
/*				returned value is possible between 0.0	*/
/*				and 100.0 %. If NULL is used as pointer,*/
/*				the parameter is ignored. If the sensor	*/
/*				device does not support humidity values,*/
/*				or no humidity value is available, the	*/
/*				returned value is 0.0.			*/
/*									*/
/* pfValTemp	float *		Pointer to a float variable (4-bytes	*/
/*				IEEE floating point) for receiving the	*/
/*				latest temperature measuring value. The */
/*				returned value is possible between -40.0*/
/*				and +120.0 C. If NULL is used as ptr.,	*/
/*				the parameter is ignored. If the sensor	*/
/*				device does not support temperature	*/
/*				measurings, or no value is available,	*/
/*				the returned value is -40.0 C.		*/
/*									*/
/* pfValDew	float *		Pointer to a float variable (4-bytes	*/
/*				IEEE floating point) for receiving the	*/
/*				latest calculated dewpoint value. The	*/
/*				returned value is possible between -40.0*/
/*				and +120.0 C. If NULL is used as ptr.,	*/
/*				this parameter is ignored. If the dew-	*/
/*				point cannot be calculated, -40.0 C is	*/
/*				returned.				*/
/*									*/
/* Return type:	LRESULT							*/
/* 									*/
/* The function returns a status code of type 'SENS_...':		*/

#define SENS_READ_BY_SERIAL_NUMBER 0	/* Parameter = serial number	*/
#define SENS_READ_BY_INDEX	   1	/* Parameter = device index	*/

//_declspec(dllexport)	LRESULT	CALLBACK SensReadValuesA(PVOID Parameter, BOOL Mode,
//							 float * pfValRH, float * pfValTemp, float * pfValDew);
//_declspec(dllexport)	LRESULT	CALLBACK SensReadValuesW(PVOID Parameter, BOOL Mode,
//							 float * pfValRH, float * pfValTemp, float * pfValDew);

#ifdef UNICODE
 #define	SensReadValues	SensReadValuesW 
#else
 //#define	SensReadValues	SensReadValuesA
#endif


/* Function enables or disables the heating of a UFT75-AT sensor device.*/
/* This option is only supported since firmware version 2.0.00:		*/
/* 									*/
/* Parameter:	Type:		Description:  				*/
/*									*/
/* Parameter	PVOID		Parameter, depending on 'bMode'. If	*/
/*				SENS_READ_BY_SERIAL_NUMBER is used,	*/
/*				the 'Parameter' is a pointer to a null-	*/
/*				terminated ASCII string, which contains	*/
/*				the complete device serial number.	*/
/*				If 'bMode' is SENS_READ_BY_INDEX, the	*/
/*				'Parameter' is the device index, used	*/
/*				to search the sensor using the function	*/
/*                              SensFindDevice(n, ...).			*/
/*									*/
/* Mode		BOOL		Addressing mode for device selection.	*/
/*				As described before, the sensor device	*/
/*				either can be identified by the device	*/
/*				serial number or the device index.	*/
/*									*/
/* bEnable	BOOL		TRUE, if the heating should be enabled,	*/
/*				or FALSE if the heating should be dis-	*/
/*				abled.					*/
/*									*/
/* Return type:	LRESULT							*/
/* 									*/
/*									*/
/* The function returns a status code of type 'SENS_...':		*/

//_declspec(dllexport)	LRESULT	CALLBACK SensSetHeatingA(PVOID Parameter, BOOL Mode, BOOL bEnable);
//_declspec(dllexport)	LRESULT	CALLBACK SensSetHeatingW(PVOID Parameter, BOOL Mode, BOOL bEnable);

#ifdef UNICODE
 #define	SensSetHeating	SensSetHeatingW 
#else
 //#define	SensSetHeating	SensSetHeatingA
#endif


/* Function returns TRUE, if the sensor device configuration (new device*/
/* was added or device was removed from the USB) has changed since last	*/
/* call:								*/
/* 									*/
/* Parameter:	Type:		Description:  				*/
/*									*/
/* none		---		No parameters required.			*/
/* 									*/
/* Return type:	BOOL							*/
/* 									*/
/* The function returns TRUE, if a device change notification on USB	*/
/* has occured since last call of this function, e.g. if a new sensor	*/
/* was connected to the PC or a sensor device was removed from the USB.	*/
/* If the function returns TRUE, you should determine whether new	*/
/* devices were added in between or if the devices are still available.	*/

//_declspec(dllexport)	BOOL	CALLBACK SensGetChangeFlagA(VOID);
//_declspec(dllexport)	BOOL	CALLBACK SensGetChangeFlagW(VOID);

#ifdef UNICODE
 #define	SensGetChangeFlag	SensGetChangeFlagW 
#else
 //#define	SensGetChangeFlag	SensGetChangeFlagA
#endif


/* Function waits until sensor searching has finished or a timeout	*/
/* occurs:								*/
/* 									*/
/* Parameter:	Type:		Description:  				*/
/*									*/
/* none		---		No parameters required.			*/
/* 									*/
/* Return type:	BOOL							*/
/* 									*/
/* Funtion returns TRUE, if sensor scan was finished or FALSE on	*/
/* timeout or any other error. It can be used to synchronisize the	*/
/* application threads with the device detection threads of this	*/
/* library. A new scan procedure is performed after startup of the DLL	*/
/* and after any USB device change notification. A standard device scan	*/
/* should not need more than 500 milliseconds if the DLL can claim the	*/
/* needed processing power.						*/

//_declspec(dllexport)	BOOL	CALLBACK SensWaitReadyA(LONG nTimeout);
//_declspec(dllexport)	BOOL	CALLBACK SensWaitReadyW(LONG nTimeout);

#ifdef UNICODE
 #define	SensWaitReady		SensWaitReadyA 
#else
 //#define	SensWaitReady		SensWaitReadyW
#endif

